@@ -6,13 +6,10 @@ import git
 import json
 import logging
 import os
-import random
-import re
 import requests
 import requests_cache
 import rich
 import shutil
-import time
 
 import nf_core
 import nf_core.create
@@ -79,6 +76,12 @@ class PipelineSync(object):
         self.gh_repo = gh_repo
         self.pr_url = ""
 
+        self.gh_api = nf_core.utils.gh_api
+        if self.gh_username and "GITHUB_AUTH_TOKEN" in os.environ:
+            self.gh_api.auth = requests.auth.HTTPBasicAuth(self.gh_username, os.environ["GITHUB_AUTH_TOKEN"])
+        self.gh_api.return_ok = [200, 201]
+        self.gh_api.lazy_init()
+
     def sync(self):
         """Find workflow attributes, create a new template pipeline on TEMPLATE"""
 
@@ -316,75 +319,28 @@ class PipelineSync(object):
         ).format(tag=nf_core.__version__)
 
         # Make new pull-request
-        pr_content = {
-            "title": pr_title,
-            "body": pr_body_text,
-            "maintainer_can_modify": True,
-            "head": self.merge_branch,
-            "base": self.from_branch,
-        }
-
         stderr = rich.console.Console(stderr=True, force_terminal=nf_core.utils.rich_force_colors())
-
-        while True:
+        log.debug("Submitting PR to GitHub API")
+        with self.gh_api.cache_disabled():
             try:
-                log.debug("Submitting PR to GitHub API")
-                returned_data_prettyprint = ""
-                r_headers_pp = ""
-                with requests_cache.disabled():
-                    r = requests.post(
-                        url="https://api.github.com/repos/{}/pulls".format(self.gh_repo),
-                        data=json.dumps(pr_content),
-                        auth=requests.auth.HTTPBasicAuth(self.gh_username, os.environ["GITHUB_AUTH_TOKEN"]),
-                    )
-                try:
-                    self.gh_pr_returned_data = json.loads(r.content)
-                    returned_data_prettyprint = json.dumps(dict(self.gh_pr_returned_data), indent=4)
-                    r_headers_pp = json.dumps(dict(r.headers), indent=4)
-                except:
-                    self.gh_pr_returned_data = r.content
-                    returned_data_prettyprint = r.content
-                    r_headers_pp = r.headers
-                    log.error("Could not parse JSON response from GitHub API!")
-                    stderr.print_exception()
-
-                # Dump the responses to the log just in case..
-                log.debug(f"PR response from GitHub. Data:\n{returned_data_prettyprint}\n\nHeaders:\n{r_headers_pp}")
-
-                # PR worked
-                if r.status_code == 201:
-                    self.pr_url = self.gh_pr_returned_data["html_url"]
-                    log.debug(f"GitHub API PR worked, return code 201")
-                    log.info(f"GitHub PR created: {self.gh_pr_returned_data['html_url']}")
-                    break
-
-                # Returned 403 error - too many simultaneous requests
-                # https://github.com/nf-core/tools/issues/911
-                if r.status_code == 403:
-                    log.debug(f"GitHub API PR failed with 403 error")
-                    wait_time = float(re.sub("[^0-9]", "", str(r.headers.get("Retry-After", 0))))
-                    if wait_time == 0:
-                        log.debug("Couldn't find 'Retry-After' header, guessing a length of time to wait")
-                        wait_time = random.randrange(10, 60)
-                    log.warning(
-                        f"Got 403 code - probably the abuse protection. Trying again after {wait_time} seconds.."
-                    )
-                    time.sleep(wait_time)
-
-                # Something went wrong
-                else:
-                    raise PullRequestException(
-                        f"GitHub API returned code {r.status_code}: \n\n{returned_data_prettyprint}\n\n{r_headers_pp}"
-                    )
-            # Don't catch the PullRequestException that we raised inside
-            except PullRequestException:
-                raise
-            # Do catch any other exceptions that we hit
+                r = self.gh_api.request_retry(
+                    f"https://api.github.com/repos/{self.gh_repo}/pulls",
+                    post_data={
+                        "title": pr_title,
+                        "body": pr_body_text,
+                        "maintainer_can_modify": True,
+                        "head": self.merge_branch,
+                        "base": self.from_branch,
+                    },
+                )
             except Exception as e:
                 stderr.print_exception()
-                raise PullRequestException(
-                    f"Something went badly wrong - {e}: \n\n{returned_data_prettyprint}\n\n{r_headers_pp}"
-                )
+                raise PullRequestException(f"Something went badly wrong - {e}")
+            else:
+                self.gh_pr_returned_data = r.json()
+                self.pr_url = self.gh_pr_returned_data["html_url"]
+                log.debug(f"GitHub API PR worked, return code 201")
+                log.info(f"GitHub PR created: {self.gh_pr_returned_data['html_url']}")
 
     def close_open_template_merge_prs(self):
         """Get all template merging branches (starting with 'nf-core-template-merge-')
@@ -395,11 +351,8 @@ class PipelineSync(object):
 
         # Look for existing pull-requests
         list_prs_url = f"https://api.github.com/repos/{self.gh_repo}/pulls"
-        with requests_cache.disabled():
-            list_prs_request = requests.get(
-                url=list_prs_url,
-                auth=requests.auth.HTTPBasicAuth(self.gh_username, os.environ["GITHUB_AUTH_TOKEN"]),
-            )
+        with self.gh_api.cache_disabled():
+            list_prs_request = self.gh_api.get(list_prs_url)
         try:
             list_prs_json = json.loads(list_prs_request.content)
             list_prs_pp = json.dumps(list_prs_json, indent=4)
@@ -437,20 +390,12 @@ class PipelineSync(object):
             f"This pull-request is now outdated and has been closed in favour of {self.pr_url}\n\n"
             f"Please use {self.pr_url} to merge in the new changes from the nf-core template as soon as possible."
         )
-        with requests_cache.disabled():
-            comment_request = requests.post(
-                url=pr["comments_url"],
-                data=json.dumps({"body": comment_text}),
-                auth=requests.auth.HTTPBasicAuth(self.gh_username, os.environ["GITHUB_AUTH_TOKEN"]),
-            )
+        with self.gh_api.cache_disabled():
+            self.gh_api.post(url=pr["comments_url"], data=json.dumps({"body": comment_text}))
 
         # Update the PR status to be closed
-        with requests_cache.disabled():
-            pr_request = requests.patch(
-                url=pr["url"],
-                data=json.dumps({"state": "closed"}),
-                auth=requests.auth.HTTPBasicAuth(self.gh_username, os.environ["GITHUB_AUTH_TOKEN"]),
-            )
+        with self.gh_api.cache_disabled():
+            pr_request = self.gh_api.patch(url=pr["url"], data=json.dumps({"state": "closed"}))
         try:
             pr_request_json = json.loads(pr_request.content)
             pr_request_pp = json.dumps(pr_request_json, indent=4)
